getLoadedGroups static method

Iterable<String> getLoadedGroups()

Returns the groups that the currently loaded fonts are in. There will not be duplicate group entries if there are multiple fonts in the same group.

Implementation

static Iterable<String> getLoadedGroups() {
  final Set<String> loadedGroups = Set<String>();

  void getLoadedGroups(String k) {
    final _FontRecord record = _loadedFonts[k]!;
    loadedGroups.addAll(record.groupUses.keys);
  }

  _loadedFonts.keys.forEach(getLoadedGroups);
  return loadedGroups;
}